"use strict";

var _postcss = require("postcss");

var _postcss2 = _interopRequireDefault(_postcss);

var _postcssValueParser = require("postcss-value-parser");

var _postcssValueParser2 = _interopRequireDefault(_postcssValueParser);

var _icssUtils = require("icss-utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var plugin = "postcss-plugin-import"; /* eslint-env node */


var getArg = function getArg(nodes) {
  return nodes.length !== 0 && nodes[0].type === "string" ? nodes[0].value : _postcssValueParser2.default.stringify(nodes);
};

var getUrl = function getUrl(node) {
  if (node.type === "function" && node.value === "url") {
    return getArg(node.nodes);
  }
  if (node.type === "string") {
    return node.value;
  }
  return "";
};

var parseImport = function parseImport(params) {
  var _valueParser = (0, _postcssValueParser2.default)(params),
      nodes = _valueParser.nodes;

  if (nodes.length === 0) {
    return null;
  }
  var url = getUrl(nodes[0]);
  if (url.trim().length === 0) {
    return null;
  }
  return {
    url,
    media: _postcssValueParser2.default.stringify(nodes.slice(1)).trim()
  };
};

var isExternalUrl = function isExternalUrl(url) {
  return (/^\w+:\/\//.test(url) || url.startsWith("//")
  );
};

var walkImports = function walkImports(css, callback) {
  css.each(function (node) {
    if (node.type === "atrule" && node.name.toLowerCase() === "import") {
      callback(node);
    }
  });
};

module.exports = _postcss2.default.plugin(plugin, function () {
  return function (css, result) {
    var imports = {};
    walkImports(css, function (atrule) {
      if (atrule.nodes) {
        return result.warn("It looks like you didn't end your @import statement correctly. " + "Child nodes are attached to it.", { node: atrule });
      }
      var parsed = parseImport(atrule.params);
      if (parsed === null) {
        return result.warn(`Unable to find uri in '${atrule.toString()}'`, {
          node: atrule
        });
      }
      if (!isExternalUrl(parsed.url)) {
        atrule.remove();
        imports[`'${parsed.url}'`] = {
          import: "default" + (parsed.media.length === 0 ? "" : ` ${parsed.media}`)
        };
      }
    });
    css.prepend((0, _icssUtils.createICSSRules)(imports, {}));
  };
});